@@ -15,6 +15,20 @@ import ipaddress
 type Key[T: (str, int)] = T
 type JWT[T] = T
 
+# Integer type aliases for ClickHouse integer types
+type Int8 = Annotated[int, "int8"]
+type Int16 = Annotated[int, "int16"]
+type Int32 = Annotated[int, "int32"]
+type Int64 = Annotated[int, "int64"]
+type UInt8 = Annotated[int, "uint8"]
+type UInt16 = Annotated[int, "uint16"]
+type UInt32 = Annotated[int, "uint32"]
+type UInt64 = Annotated[int, "uint64"]
+
+# Float type aliases for ClickHouse float types
+type Float32 = Annotated[float, "float32"]
+type Float64 = Annotated[float, "float64"]
+
 
 @dataclasses.dataclass(frozen=True)  # a BaseModel in the annotations will confuse pydantic
 class ClickhousePrecision:
@@ -26,6 +40,11 @@ class ClickhouseSize:
     size: int
 
 
+@dataclasses.dataclass(frozen=True)
+class ClickhouseFixedStringSize:
+    size: int
+
+
 @dataclasses.dataclass(frozen=True)
 class ClickhouseDefault:
     expression: str
@@ -61,6 +80,23 @@ def clickhouse_datetime64(precision: int) -> Type[datetime]:
     return Annotated[datetime, ClickhousePrecision(precision=precision)]
 
 
+def FixedString(size: int) -> ClickhouseFixedStringSize:
+    """
+    Creates a FixedString(N) annotation for fixed-length strings.
+
+    ClickHouse stores exactly N bytes, padding shorter values with null bytes.
+    Values exceeding N bytes will raise an exception.
+
+    Use for fixed-length data like hashes, IPs, UUIDs, MAC addresses.
+
+    Example:
+        md5_hash: Annotated[str, FixedString(16)]  # 16-byte MD5
+        sha256: Annotated[str, FixedString(32)]    # 32-byte SHA256
+        ipv6: Annotated[str, FixedString(16)]      # 16-byte IPv6
+    """
+    return ClickhouseFixedStringSize(size=size)
+
+
 type Point = Annotated[tuple[float, float], "Point"]
 type Ring = Annotated[list[tuple[float, float]], "Ring"]
 type LineString = Annotated[list[tuple[float, float]], "LineString"]
@@ -279,7 +315,26 @@ def py_type_to_column_type(t: type, mds: list[Any]) -> Tuple[bool, list[Any], Da
     data_type: DataType
 
     if t is str:
-        data_type = "String"
+        # Check for FixedString annotation
+        fixed_string_size = next(
+            (md.size for md in mds if isinstance(md, ClickhouseFixedStringSize)),
+            None
+        )
+        if fixed_string_size:
+            data_type = f"FixedString({fixed_string_size})"
+        else:
+            data_type = "String"
+    elif t is bytes:
+        # Check for FixedString annotation
+        fixed_string_size = next(
+            (md.size for md in mds if isinstance(md, ClickhouseFixedStringSize)),
+            None
+        )
+        if fixed_string_size:
+            data_type = f"FixedString({fixed_string_size})"
+        else:
+            # Regular bytes without FixedString annotation
+            data_type = "String"
     elif t is int:
         # Check for int size annotations
         int_size = next((md for md in mds if isinstance(md, str) and re.match(r'^u?int\d+$', md)), None)
@@ -437,9 +492,13 @@ def py_type_to_column_type(t: type, mds: list[Any]) -> Tuple[bool, list[Any], Da
 def _to_columns(model: type[BaseModel]) -> list[Column]:
     """Convert Pydantic model fields to Column definitions."""
     columns = []
+    # Get raw annotations from the model class to preserve type aliases
+    raw_annotations = getattr(model, '__annotations__', {})
+
     for field_name, field_info in model.model_fields.items():
-        # Get the field type annotation
-        field_type = field_info.annotation
+        # Use raw annotation if available (preserves type aliases and their metadata)
+        # Fall back to field_info.annotation if not found in __annotations__
+        field_type = raw_annotations.get(field_name, field_info.annotation)
         if field_type is None:
             raise ValueError(f"Missing type for {field_name}")
         primary_key, field_type = handle_key(field_type)
